@@ -25,13 +25,17 @@
 #include <vector>
 
 #include "Environment.h"
-#include "Parser.h"
+#include "parser.h"
+
+namespace scanner {
+class Scan;
+}
 
 class GuessnetEnvironment : public Environment
 {
 protected:
 	// List of tests to perform
-	std::vector<const Scan*> _scans;
+	std::vector<const scanner::Scan*> _scans;
 
 	virtual void parseConfigFile() = 0;
 	
@@ -39,7 +43,7 @@ public:
 	virtual ~GuessnetEnvironment() {}
 	static void init(int argc, const char* argv[]);
 	static GuessnetEnvironment& get() throw ();
-	const std::vector<const Scan*> scans() throw () { return _scans; }
+	const std::vector<const scanner::Scan*> scans() throw () { return _scans; }
 };
 
 
